pub struct TransactionInfo {Show 14 fields
pub version: String,
pub hash: String,
pub state_change_hash: String,
pub event_root_hash: String,
pub state_checkpoint_hash: Option<String>,
pub gas_used: String,
pub success: bool,
pub vm_status: String,
pub accumulator_root_hash: String,
pub changes: Vec<WriteSetChange>,
pub events: Vec<Event>,
pub timestamp: Option<String>,
pub max_gas_amount: Option<String>,
pub transaction_type: TransactionType,
}Expand description
Represents a transaction on the Aptos blockchain Contains all relevant information about a transaction including metadata, payload, and execution results
Fields
version: Stringhash: Stringstate_change_hash: Stringevent_root_hash: Stringstate_checkpoint_hash: Option<String>gas_used: Stringsuccess: boolvm_status: Stringaccumulator_root_hash: Stringchanges: Vec<WriteSetChange>events: Vec<Event>timestamp: Option<String>max_gas_amount: Option<String>transaction_type: TransactionTypeImplementations
Sourceimpl TransactionInfo
impl TransactionInfo
Sourcepub fn is_successful(&self) -> bool
pub fn is_successful(&self) -> bool
Check if the transaction was successful
Sourcepub fn get_timestamp(&self) -> Option<u64>
pub fn get_timestamp(&self) -> Option<u64>
Get transaction timestamp
Sourcepub fn get_gas_used(&self) -> Option<u64>
pub fn get_gas_used(&self) -> Option<u64>
Get the amount of gas used
Sourcepub fn is_user_transaction(&self) -> bool
pub fn is_user_transaction(&self) -> bool
Check whether it is a user transaction
Sourcepub fn get_sender(&self) -> Option<&str>
pub fn get_sender(&self) -> Option<&str>
Get the sender address in this transaction.
pub fn get_spent_token(&self) -> Option<(String, u64)>
pub fn get_received_token(&self) -> Option<(String, u64)>
pub fn get_spent_token_eth(&self) -> Option<(String, f64)>
pub fn get_received_token_eth(&self) -> Option<(String, f64)>
pub fn getDirection(&self) -> String
pub fn calculate_all_token_balances(&self)
pub fn get_liquidity_pool_addresses(&self) -> Vec<String>
pub fn get_dex_names(&self) -> Vec<String>